#
# spec file for package python-plotly
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-plotly
Version:        2.5.1
Release:        lp151.2.2
Summary:        Library for collaborative, interactive, publication-quality graphs
License:        MIT
Group:          Development/Languages/Python
Url:            https://plot.ly/api/python
Source:         https://files.pythonhosted.org/packages/source/p/plotly/plotly-%{version}.tar.gz
BuildRequires:  %{python_module decorator >= 4.0.6}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module jupyter_nbformat >= 4.2}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-decorator >= 4.0.6
Requires:       python-jupyter_nbformat >= 4.2
Requires:       python-pytz
Requires:       python-requests
Requires:       python-six
Recommends:     python-jupyter_ipython
Recommends:     python-jupyter_ipywidgets
Recommends:     python-jupyter_notebook
Recommends:     python-matplotlib >= 1.3.1
Recommends:     python-numpy
Recommends:     python-pandas
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Use this package to make collaborative, interactive,
publication-quality graphs from Python on https://plot.ly.

Plotly is an online collaborative data analysis and graphing tool. The
Python API allows you to access all of Plotly's functionality from Python.
Plotly figures are shared, tracked, and edited all online and the data is
always accessible from the graph.

%prep
%setup -q -n plotly-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst
%{python_sitelib}/*

%changelog
* Thu Apr 19 2018 toddrme2178@gmail.com
- update to version 2.5.1
  * Fixed
    + `plotly.figure_factory.create_choropleth` now works in Windows without raising an OSError. The module now uses cross-platform path tools from `os` to manipulate and manage the shapefiles contained in this package.
- update to version 2.5.0
  * Fixed
    + `import plotly.figure_factory` does not fail if `pandas` is not installed. See  https://github.com/plotly/plotly.py/pull/958
  * Added
    + New parameter `fill_percent` to the `.insert` method for the dashboards API. You can now insert a box into the dashboard layout and specify what proportion of the original container box it will occupy. Run `help(plotly.dashboard_objs.Dashboard.insert)` for more information on `fill_percent`.
  * Updated
    + Updated `plotly.min.js` to version 1.35.2.
  - New features include adding an `automargin` attribute to cartesian axes and a layout `grids` attribute for easy subplot generation.
  - See [the plotly.js CHANGELOG](https://github.com/plotly/plotly.js/blob/master/CHANGELOG.md#1352----2018-03-09) for additional information regarding the updates.
    + `plotly.figure_factory.create_choropleth` has changed some of the default plotting options:
  - 'offline_mode' param has been removed from call signature.
  - Persistent selection api for the centroid points is automatically enabled. See https://plot.ly/python/reference/#scatter-selected and https://plot.ly/python/reference/#scatter-unselected for details
  - FIPS values that appear on hover are 0-padded to ensure they are 5 digits.
  - `hover_info='none'` is now default for the county lines data.
* Thu Feb 22 2018 arun@gmx.de
- update to version 2.4.1:
  * Fixed
    + The required shapefiles to generate the choropleths via
    plotly.figure_factory.create_choropleth are now shipped in the
    package data.
* Mon Feb 19 2018 arun@gmx.de
- update to version 2.4.0:
  * Added
    + County Choropleth figure factory. Call
    help(plotly.figure_factory.create_choropleth) for examples and
    how to get started making choropleths of US counties with the
    Python API.
    Note: import plotly.figure_factory as ff is broken and 2.4.0
    must be yanked ASAP. Efforts to fix this version are currently
    underway.
* Sat Feb 10 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.3.0:
  * Fixed
    + Merged pull request that fixes GraphWidget for IPython > v6
  * Updated
    + Updated plotly.min.js to version 1.33.1.
    o New plot types include a violin trace type.
    o New features include completely rewritten scattergl using regl
    and a completely rewritten polar chart renderer.
    o See the plotly.js CHANGELOG for additional information regarding
    the updates.
* Wed Dec  6 2017 arun@gmx.de
- update to version 2.2.3:
  * Added
    + -column_width and row_width parameters for
    plotly.tools.make_subplots. Call
    help(plotly.tools.make_subplots) for documentation.
  * Updated plotly.min.js to version 1.31.2.
    + Fixes include adjustments to table trace for offline plotting.
    + See the plotly.js CHANGELOG for additional information regarding
    the updates.
* Sun Nov 26 2017 arun@gmx.de
- update to version 2.2.2:
  * bullet chart figure factory. Call
    help(plotly.figure_factory.create_bullet) for examples and how to
    get started making bullet charts with the API.
* Fri Oct 27 2017 arun@gmx.de
- update to version 2.2.1:
  * presentation objects now added to setup.py
- changes from version 2.2.0:
  * Added
    + NEW Presentations API for Python! Run
    help(plotly.presentation_objs.Presentations) for help or check
    out the new documentation
* Fri Oct 13 2017 arun@gmx.de
- update to version 2.1.0:
  * Updated plotly.min.js to version 1.31.0.
    + New features include a table trace type.
    + See the plotly.js CHANGELOG for additional information regarding
    the updates.
* Sat Oct  7 2017 arun@gmx.de
- update to version 2.0.16:
  * Updated plotly.min.js to version 1.31.0 for plotly.offline.
    See the plotly.js CHANGELOG for additional information regarding the updates.
* Tue Oct  3 2017 arun@gmx.de
- update to version 2.0.15:
  * Updated plotly.min.js to version 1.30.0 for plotly.offline.
    + See the plotly.js CHANGELOG for additional information regarding
    the updates.
* Thu Aug 17 2017 toddrme2178@gmail.com
- Update to python-plotly-2.0.14
- Fix imports
* Wed Aug  2 2017 alarrosa@suse.com
- Update to python-plotly-2.0.12
- Use singlespec macros
* Wed Apr 29 2015 toddrme2178@gmail.com
- Initial version
